Learn R Programming

bayesRecon (version 1.0.2)

.lowest_lev: Find rows corresponding to the lowest level

Description

Identifies the rows of aggregation matrix A that correspond to the lowest hierarchical level (i.e., the most disaggregated upper variables that collectively sum to all bottom variables).

Usage

.lowest_lev(A)

Value

Integer vector of row indices corresponding to the lowest level

Arguments

A

Aggregation matrix (must be hierarchical)