dot-lowest_lev: Find rows corresponding to the lowest level

.lowest_levR Documentation

Find rows corresponding to the lowest level

Description

Identifies the rows of aggregation matrix A that correspond to the lowest hierarchical level (i.e., the most disaggregated upper variables that collectively sum to all bottom variables).

Usage

.lowest_lev(A)

Arguments

A

Aggregation matrix (must be hierarchical)

Value

Integer vector of row indices corresponding to the lowest level


bayesRecon documentation built on March 8, 2026, 9:08 a.m.