| .compute_naive_cov | R Documentation |
Estimates via shrinkage the covariance matrix of the residuals of the naive or seasonal naive forecasts. If the frequency of the time series is > 1, the function chooses between the two methods series-by-series according to a selection criterion. If the frequency is 1 or is not provided, only the naive residuals are used.
.compute_naive_cov(y_train, freq = NULL, criterion = "RSS")
y_train |
Multivariate time series object or numeric matrix of historical
observations, with dimensions |
freq |
Positive integer seasonal frequency (optional).
If not provided and |
criterion |
Character string used when |
A numeric n x n shrinkage covariance matrix estimated with
schaferStrimmer_cov().
schaferStrimmer_cov(), reconc_t()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.