| .lowest_lev | R Documentation |
Identifies the rows of aggregation matrix A that correspond to the lowest hierarchical level (i.e., the most disaggregated upper variables that collectively sum to all bottom variables).
.lowest_lev(A)
A |
Aggregation matrix (must be hierarchical) |
Integer vector of row indices corresponding to the lowest level
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.