| reconc_BUIS | R Documentation |
Uses the Bottom-Up Importance Sampling algorithm to draw samples from the reconciled forecast distribution, obtained via conditioning.
reconc_BUIS(
A,
base_fc,
in_type,
distr,
num_samples = 20000,
suppress_warnings = FALSE,
return_upper = TRUE,
seed = NULL
)
A |
aggregation matrix (n_upper x n_bottom). |
base_fc |
A list containing the base_forecasts, see details. |
in_type |
A string or a list of length n_upper + n_bottom. If it is a list the i-th element is a string with two possible values:
If it |
distr |
A string or a list of length n_upper + n_bottom describing the type of base forecasts. If it is a list the i-th element is a string with two possible values:
If |
num_samples |
Number of samples drawn from the reconciled distribution.
This is ignored if |
suppress_warnings |
Logical. If |
return_upper |
Logical, whether to return the reconciled parameters for the upper variables (default is TRUE). |
seed |
Seed for reproducibility. |
The parameter base_fc is a list containing n = n_upper + n_bottom elements.
The first n_upper elements of the list are the upper base forecasts, in the order given by the rows of A.
The elements from n_upper+1 until the end of the list are the bottom base forecasts, in the order given by the columns of A.
The i-th element depends on the values of in_type[[i]] and distr[[i]].
If in_type[[i]]='samples', then base_fc[[i]] is a vector containing samples from the base forecast distribution.
If in_type[[i]]='params', then base_fc[[i]] is a list containing the estimated:
mean and sd for the Gaussian base forecast if distr[[i]]='gaussian', see Normal;
lambda for the Poisson base forecast if distr[[i]]='poisson', see Poisson;
size and prob (or mu) for the negative binomial base forecast if distr[[i]]='nbinom', see NegBinomial.
See the description of the parameters in_type and distr for more details.
Warnings are triggered from the Importance Sampling step if:
weights are all zeros, then the upper is ignored during reconciliation;
the effective sample size is < 200;
the effective sample size is < 1% of the sample size (num_samples if in_type is 'params' or the size of the base forecast if if in_type is 'samples').
Note that warnings are an indication that the base forecasts might have issues. Please check the base forecasts in case of warnings.
A list containing the reconciled forecasts. The list has the following named elements:
bottom_rec_samples: a matrix (n_bottom x num_samples) containing the reconciled samples for the bottom time series;
upper_rec_samples: (only if return_upper = TRUE) a matrix (n_upper x num_samples) containing the reconciled samples for the upper time series.
Zambon, L., Azzimonti, D. & Corani, G. (2024). Efficient probabilistic reconciliation of forecasts for real-valued and count time series. Statistics and Computing 34 (1), 21. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/s11222-023-10343-y")}.
reconc_gaussian()
library(bayesRecon)
# Create a minimal hierarchy with 2 bottom and 1 upper variable
rec_mat <- get_reconc_matrices(agg_levels = c(1, 2), h = 2)
A <- rec_mat$A
S <- rec_mat$S
# 1) Gaussian base forecasts
# Set the parameters of the Gaussian base forecast distributions
mu1 <- 2
mu2 <- 4
muY <- 9
mus <- c(muY, mu1, mu2)
sigma1 <- 2
sigma2 <- 2
sigmaY <- 3
sigmas <- c(sigmaY, sigma1, sigma2)
base_fc <- list()
for (i in 1:length(mus)) {
base_fc[[i]] <- list(mean = mus[[i]], sd = sigmas[[i]])
}
# Sample from the reconciled forecast distribution using the BUIS algorithm
buis <- reconc_BUIS(A, base_fc,
in_type = "params",
distr = "gaussian", num_samples = 100000, seed = 42
)
samples_buis <- rbind(buis$upper_rec_samples, buis$bottom_rec_samples)
# In the Gaussian case, the reconciled distribution is still Gaussian and can be
# computed in closed form
Sigma <- diag(sigmas^2) # transform into covariance matrix
analytic_rec <- reconc_gaussian(A,
base_fc_mean = mus,
base_fc_cov = Sigma
)
# Compare the reconciled means obtained analytically and via BUIS
print(c(S %*% analytic_rec$bottom_rec_mean))
print(rowMeans(samples_buis))
# 2) Poisson base forecasts
# Set the parameters of the Poisson base forecast distributions
lambda1 <- 2
lambda2 <- 4
lambdaY <- 9
lambdas <- c(lambdaY, lambda1, lambda2)
base_fc <- list()
for (i in 1:length(lambdas)) {
base_fc[[i]] <- list(lambda = lambdas[i])
}
# Sample from the reconciled forecast distribution using the BUIS algorithm
buis <- reconc_BUIS(A, base_fc,
in_type = "params",
distr = "poisson", num_samples = 100000, seed = 42
)
samples_buis <- rbind(buis$upper_rec_samples, buis$bottom_rec_samples)
# Print the reconciled means
print(rowMeans(samples_buis))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.